@@ -103,15 +103,14 @@ def get_files(files):
     Takes a file variable and returns the list of files
 
     :param files: If a falsy value, returns an empty list.
-                  If a string, is turned into a list then globbed like a list (see below).
+                  If a string, is turned into a list then treated like a list
                   If a set, just returns a list of the paths in the set completely unchanged
                   If a tuple of strings, each string will have os.path.expanduser
                   and os.path.abspath ran on them, then they will be returned.
-                  If a list of strings, each string is ran through glob.glob (or formic) and
-                  returned as a list containing all of the unique paths returned from glob.glob.
-                  If list of dicts, each dict is ran through _get_files (or formic) and
+                  If a list of strings, each string is ran through formic and returned as a list
+                  If list of dicts, each dict is ran through _get_files and
                   returns the list of unique paths retrieved from all the calls.
-                  If dict is ran through _get_files, or formic if no 'path' key exists
+                  If dict is ran through _get_files
 
     :returns: List of file strings
     """
@@ -127,31 +126,43 @@ def get_files(files):
     if isinstance(files, tuple):
         return [os.path.abspath(os.path.expanduser(f)) for f in files]
 
+    if isinstance(files, FileSet):
+        return list(FileSet)
+
     if isinstance(files, list):
         if isinstance(files[0], basestring):
-            files = [os.path.abspath(os.path.expanduser(f)) for f in files]
             # If there is a double-wildcard in the name, we'll run it through formic instead
-            files = [list(FileSet(f)) if '**' in f else glob.glob(f) for f in files]
+            files = [list(FileSet(f)) for f in files]
             return list(set(itertools.chain(*files)))
 
         elif isinstance(files[0], dict):
             # Run through formic if we're not sending a path. Path is always required
             # for the get_files function
-            files = [_get_files(**f) if 'path' in f else list(FileSet(**f)) for f in files]
+            files = [_get_files(**f) for f in files]
             return list(set(itertools.chain(*files)))
 
     if isinstance(files, dict):
-        return _get_files(**files) if 'path' in files else list(FileSet(**files))
+        return _get_files(**files)
 
 
 def run_function_list(fns, predicate=None):
     """
-    Runs a list of functions
+    Runs a list of functions.
+    Tolerant of passing in a single function
+
     :param fns: list of dicts with three keys: fn (function object),
                                                args (list of args),
                                                kwargs (dict of kwargs)
     :param predicate: if this function returns false, given the current function, it will not be ran
     """
+
+    if not fns:
+        return
+
+    # Allow for sending in a single function
+    if not isinstance(fns, (list, tuple, set)):
+        fns = [fns]
+
     for fn in fns:
         if predicate and not predicate(fn):
             continue
